@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::AuthorityFromModule; # git description: v0.005-2-gff194ff
-# ABSTRACT: Add metadata to your distribution indicating what module to copy PAUSE permissions from
+package Dist::Zilla::Plugin::AuthorityFromModule; # git description: v0.006-15-gdad604f
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+# ABSTRACT: (DEPRECATED) Add metadata to your distribution indicating what module to copy PAUSE permissions from
 # KEYWORDS: distribution metadata authority permissions PAUSE users
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -53,6 +53,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         module => $self->_module_name,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -89,11 +90,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::AuthorityFromModule - Add metadata to your distribution indicating what module to copy PAUSE permissions from
+Dist::Zilla::Plugin::AuthorityFromModule - (DEPRECATED) Add metadata to your distribution indicating what module to copy PAUSE permissions from
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -109,13 +110,20 @@ from which module to copy L<PAUSE|http://pause.perl.org> permissions when a
 module in your distribution enters the L<PAUSE|http://pause.perl.org> index
 that has not ever previously been indexed.
 
-Note that these fields aren't actually supported yet by
-L<PAUSE|http://pause.perl.org> -- that's still to come (as is figuring out
-which field name everyone prefers, and ditching the other one).
+As of May 2016, L<PAUSE|http://pause.perl.org> now copies the permissions from the "main module" to any new modules
+entering the index for the first time, which renders this module obsolete, with all its goals met in full. There is
+no longer any need to use this module.
+
+=for stopwords Colin Newell QA Hackathon
+
+For more information, see the L<pull request that made the change|https://github.com/andk/pause/pull/222>, written
+by Colin Newell at the Perl QA Hackathon, in Rugby UK, April 2016.
 
 =head1 MOTIVATION
 
-The idea is that this is a more useful piece of data for
+NOTE: The remainder of this documentation reflects how PAUSE used to work, and is retained purely for historical reasons.
+
+The idea is (was) that this is a more useful piece of data for
 L<PAUSE|http://pause.perl.org> than C<x_authority>.  Here is how the release
 process works with C<x_authority>, using L<Moose> as an example:
 
@@ -169,20 +177,16 @@ This config is optional; it defaults to the L<main module|Dist::Zilla/main_modul
 
 =for Pod::Coverage metadata
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-AuthorityFromModule>
-(or L<bug-Dist-Zilla-Plugin-AuthorityFromModule@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-AuthorityFromModule@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
 
 =item *
 
+L<https://github.com/andk/pause/pull/222>
+
+=item *
+
 L<Dist::Zilla::Plugin::Authority>
 
 =item *
@@ -195,11 +199,24 @@ L<What is x_authority?|http://jawnsy.wordpress.com/2011/02/20/what-is-x_authorit
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-AuthorityFromModule>
+(or L<bug-Dist-Zilla-Plugin-AuthorityFromModule@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-AuthorityFromModule@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
